@@ -8,21 +8,11 @@ Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 """
 
-import sys
 import os
-from contextlib import contextmanager
 from importlib import import_module
 
-
-def first_subclass(o, c):
-    """Return first object in o that is a subclass of c
-    """
-    return first(
-        obj for obj in vars(o).itervalues()
-        if (obj is not c)
-        and isinstance(obj, type)
-        and issubclass(obj, c)
-    )
+from plib.stdlib.classtools import first_subclass
+from plib.stdlib.systools import tmp_sys_path
 
 
 def load_submodule(subtype, subdir, name, err, subcls):
@@ -45,24 +35,6 @@ def load_submodule(subtype, subdir, name, err, subcls):
     return mod, klass
 
 
-@contextmanager
-def tmp_sys_path(subdir, index=0):
-    """Temporarily munge ``sys.path`` to allow import from non-standard dir
-    """
-    
-    if subdir:
-        subdir = os.path.abspath(subdir)
-        oldpath = sys.path[:]
-        sys.path.insert(index, subdir)
-    else:
-        oldpath = None
-    try:
-        yield
-    finally:
-        if oldpath:
-            sys.path[:] = oldpath
-
-
 def load_sub(name, subtype, subdir, err, subcls):
     with tmp_sys_path(subdir):
         return load_submodule(subtype, subdir, name, err, subcls)
